@@ -2,6 +2,7 @@ import pkg_resources
 import os
 
 from sismic.interpreter import Interpreter
+from sismic.clock import UtcClock
 from sismic.io import import_from_yaml
 
 
@@ -17,4 +18,5 @@ def get_yaml_file(machine_name):
 
 def create_machine(name, **kwargs):
     full_path = get_yaml_file(name)
-    return Interpreter(import_from_yaml(filepath=full_path), **kwargs)
+    return Interpreter(import_from_yaml(filepath=full_path), clock=UtcClock(),
+                       **kwargs)
